
/*	LCD-Modus
	Wird LCD_CYRILLIC definiert, dann wird das Omega- und -Zeichen als "Custom Character" erzeugt.
	Das ist ntig, weil HD44780 mit einem anderen als dem "Standard-Zeichensatz"
	diese Zeichen nicht in ihrem ROM enthalten.
*/
//#define LCD_CYRILLIC

/*
Mit dem Define SWUART_INVERT kann festgelegt werden, ob der Software-UART normal oder invertiert sendet.
In der normalen Betriebsart sendet der UART in der blichen Logik (Low = 0; High = 1).
Das ist der Standardfall und dient zum Anschluss an einen anderen C, einen USB=>Seriell-Wandler-Chip
oder an einen Pegelwandler wie den MAX232.

In der invertierten Betriebsart sendet der UART in umgekehrter Logik, also High = 0 und Low = 1
Das entspricht der Logik der RS232-Schnittstelle von Standard-PCs.
In den meisten Fllen kann der TxD des Software-UART somit direkt mit dem RxD des PCs verbunden werden.
Laut Spezifikation ist das unzulssig, weil fr eine RS232-Schnittstelle Pegel von -3V...3V undefiniert sind.
An den meisten PCs funktioniert es aber trotzdem ohne Probleme.
Das ist eine einfache, aber etwas unsaubere Lsung...

Ist SWUART_INVERT definiert, arbeitet der UART in invertierter Betriebsart.
*/
//#define SWUART_INVERT

#define TxD PC3	//TxD-Pin des Software-UART; muss an Port C sein!



//AVR-Typenabhnggikeit
#if defined(__AVR_ATmega48__)
  #define MCU_STATUS_REG MCUCR
  #define ADC_COMP_CONTROL ADCSRB
  #define TI1_INT_FLAGS TIFR1
  #define DEFAULT_RH_FAKT  856      // mega48 1101 mV
// WITH_SELFTEST aktiviert die Selbsttest-Funktion
  #ifdef WITH_SELFTEST
  #warning "ATmega48 does NOT support SELFTEST!"
  #undef WITH_SELFTEST
  #endif
// R_MESS aktiviert die Widerstands-Messung
  #ifdef R_MESS
  #warning "ATmega48 does NOT support Resistor measuring!"
  #undef R_MESS
  #endif
// C_MESS aktiviert die Kapazitts-Messung
  #ifdef C_MESS
  #warning "ATmega48 does NOT support Capacity measuring!"
  #undef C_MESS
  #undef WITH_AUTO_REF
  #endif
// WITH_UART aktiviert die Ausgabe auf einem Software-UART
  #ifdef WITH_UART
  #warning "no UART support with ATmega48!"
  #undef WITH_UART
  #endif

  #define C_NULL (((52 * F_CPU) / 10000000)+4)
  #define PIN_RM 19
  #define PIN_RP 22

#elif defined(__AVR_ATmega88__)
  #define MCU_STATUS_REG MCUCR
  #define ADC_COMP_CONTROL ADCSRB
  #define TI1_INT_FLAGS TIFR1
  #define DEFAULT_RH_FAKT  855      // mega88 1102 mV
// LONG_HFE  aktiviert die Berechnung der Stromverstrkungs-Faktor mit long Variablen
  #define LONG_HFE
// KOLLEKTOR_SCHALTUNG aktiviert Stromverstrkungs-Messung auch in Kollektorschaltung (Emitterfolger)
  #define KOLLEKTOR_SCHALTUNG

  #define C_NULL (((52 * F_CPU) / 10000000)+4)
  #define PIN_RM 19
  #define PIN_RP 22

#elif defined(__AVR_ATmega168__)
  #define MCU_STATUS_REG MCUCR
  #define ADC_COMP_CONTROL ADCSRB
  #define TI1_INT_FLAGS TIFR1
  #define DEFAULT_RH_FAKT  831      // mega168 1129 mV
// LONG_HFE  aktiviert die Berechnung der Stromverstrkungs-Faktor mit long Variablen
  #define LONG_HFE
// KOLLEKTOR_SCHALTUNG aktiviert Stromverstrkungs-Messung auch in Kollektorschaltung (Emitterfolger)
  #define KOLLEKTOR_SCHALTUNG

  #define C_NULL (((55 * F_CPU) / 10000000)+4)
  #define PIN_RM 20
  #define PIN_RP 22

#elif defined(__AVR_ATmega328__)
  #define MCU_STATUS_REG MCUCR
  #define ADC_COMP_CONTROL ADCSRB
  #define TI1_INT_FLAGS TIFR1
  #define DEFAULT_RH_FAKT  826      // mega328 1135 mV
// LONG_HFE  aktiviert die Berechnung der Stromverstrkungs-Faktor mit long Variablen
  #define LONG_HFE
// KOLLEKTOR_SCHALTUNG aktiviert Stromverstrkungs-Messung auch in Kollektorschaltung (Emitterfolger)
  #define KOLLEKTOR_SCHALTUNG

  #define C_NULL (((52 * F_CPU) / 10000000)+4)
  #define PIN_RM 20
  #define PIN_RP 22

#else
  #define MCU_STATUS_REG MCUCSR
  #define ADC_COMP_CONTROL SFIOR
  #define TI1_INT_FLAGS TIFR
  #define DEFAULT_RH_FAKT  708      // mega8 1298 mV
// LONG_HFE  aktiviert die Berechnung der Stromverstrkungs-Faktor mit long Variablen
  #define LONG_HFE
// KOLLEKTOR_SCHALTUNG aktiviert Stromverstrkungs-Messung auch in Kollektorschaltung (Emitterfolger)
  #define KOLLEKTOR_SCHALTUNG

  #define C_NULL (((46 * F_CPU) / 10000000)+4)
  #define PIN_RM 19
  #define PIN_RP 22
#endif

#ifndef REF_KORR
 #define REF_KORR 0
#endif


